#
# spec file for package python-pygit2
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pygit2
Version:        1.17.0
Release:        bp160.1.6
Summary:        Python bindings for libgit2
License:        GPL-2.0-only
URL:            https://github.com/libgit2/pygit2
Source:         https://files.pythonhosted.org/packages/source/p/pygit2/pygit2-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module cached-property}
BuildRequires:  %{python_module cffi >= 1.17.0}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  ca-certificates
BuildRequires:  ca-certificates-mozilla
BuildRequires:  fdupes
BuildRequires:  libgit2-devel >= 1.1
BuildRequires:  libopenssl-devel
BuildRequires:  python-rpm-macros
Requires:       python-cached-property
Requires:       python-cffi >= 1.17.0
%python_subpackages

%description
Bindings for libgit2, a linkable C library for the Git version-control system.

%prep
%autosetup -p1 -n pygit2-%{version}

# do not add options to pytest
rm pytest.ini

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -rf %{buildroot}%{$python_sitearch}/pygit2/decl/
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
rm -rf pygit2
# test_no_context_lines failing on big endian
# https://github.com/libgit2/pygit2/issues/812
donttest="test_no_context_lines"
donttest="$donttest or test_push_options"
%pytest_arch -k "not ($donttest)"

%files %{python_files}
%license COPYING
%doc README.md
%{python_sitearch}/pygit2
%{python_sitearch}/pygit2-%{version}.dist-info

%changelog
* Wed Jan 29 2025 Matej Cepl <mcepl@cepl.eu>
- Remove upstreamed const-parents.patch.
* Tue Jan 28 2025 Markéta Machová <mmachova@suse.com>
- Update to 1.17.0
  * Upgrade to libgit2 1.9
  * Add certificate_check callback to Remote.ls_remotes(...)
  * Fix build with GCC 14
  * Documentation: fix typo in Repository.status(...) docstring
  * Fix tests with Python 3.13.1
* Tue Nov  5 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 1.16.0:
  - Add support for Python 3.13
  - Drop support for Python 3.9
  - New Repository.hashfile(...)
  - New Option.GET_MWINDOW_FILE_LIMIT and
    Option.SET_MWINDOW_FILE_LIMIT
  - Fix overriding certificate_check(...) callback via argument
    to RemoteCallbacks(...)
  - Add py.typed
  - Fix discover_repository(...) annotation
- Add const-parents.patch to fix FTBFS (gh#libgit2/pygit2!1324).
* Mon Aug  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.15.1
  * New `Repository.revert(...)`
  * New optional `depth` argument in submodules `add()` and `update()` methods
  * Now `Submodule.url` returns `None` when the submodule does not have a url
  * Fix use after free bug in error reporting
  * Fix `Submodule.head_id` when the submodule is not in the current HEAD tree
  * Fix `Submodule.open()` when subclassing `Repository`
  * Fix error in the test suite when running with address sanitizer
  * Annotations and documentation fixes
- Fix version number for previous changelog entry
* Wed Jun 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.15.0
  * Many deprecated features have been removed, see below
  * Upgrade to libgit2 v1.8.1
  * New `push_options` optional argument in `Repository.push(...)`
  * New support comparison of `Oid` with text string
  * Fix `CheckoutNotify.IGNORED`
  * Use default error handler when decoding/encoding paths
  * Remove setuptools runtime dependency
  * Coding style with ruff
  * Add wheels for ppc64le
  * Fix tests on EPEL8 builds for s390x
  * Deprecate `IndexEntry.hex`, use `str(IndexEntry.id)`
  * Remove deprecated `oid.hex`, use `str(oid)`
  * Remove deprecated `object.hex`, use `str(object.id)`
  * Remove deprecated `object.oid`, use `object.id`
  * Remove deprecated `Repository.add_submodule(...)`, use `Repository.submodules.add(...)`
  * Remove deprecated `Repository.lookup_submodule(...)`, use `Repository.submodules[...]`
  * Remove deprecated `Repository.init_submodules(...)`, use `Repository.submodules.init(...)`
  * Remove deprecated `Repository.update_submodule(...)`, use `Repository.submodules.update(...)`
  * Remove deprecated constants `GIT_OBJ_XXX`, use `ObjectType`
  * Remove deprecated constants `GIT_REVPARSE_XXX`, use `RevSpecFlag`
  * Remove deprecated constants `GIT_REF_XXX`, use `ReferenceType`
  * Remove deprecated `ReferenceType.OID`, use instead `ReferenceType.DIRECT`
  * Remove deprecated `ReferenceType.LISTALL`, use instead `ReferenceType.ALL`
  * Remove deprecated support for passing dicts to repository\'s `merge(...)`,
    `merge_commits(...)` and `merge_trees(...)`. Instead pass `MergeFlag` for `flags`, and
    `MergeFileFlag` for `file_flags`.
  * Remove deprecated support for passing a string for the favor argument to repository\'s
    `merge(...)`, `merge_commits(...)` and `merge_trees(...)`. Instead pass `MergeFavor`.
- Drop patches for issues fixed upstream
  * Fix-CI.patch
  * Fix-leaks-in-fetch_refspecs-and-push_refspecs.patch
  * pygit2-Upgrade_to_libgit2_v1_8_0.patch
  * pygit2-Upgrade_to_libgit2_v1_8_1-2.patch
  * pygit2-Upgrade_to_libgit2_v1_8_1.patch
- Disable test test_push_options which currently segfaults
- Update BuildRequires from setup.py
* Fri May 17 2024 Dirk Müller <dmueller@suse.com>
- add  pygit2-Upgrade_to_libgit2_v1_8_1-2.patch
  pygit2-Upgrade_to_libgit2_v1_8_1.patch: support libgit2 1.8.1
* Thu May  2 2024 Michal Suchanek <msuchanek@suse.com>
- Fix build with gcc 14
  * Fix-CI.patch
  * Fix-leaks-in-fetch_refspecs-and-push_refspecs.patch
* Sat Mar 30 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * pygit2-Upgrade_to_libgit2_v1_8_0.patch (gh#libgit2/pygit2@6d539d76b53b)
    + Backport of upstream commit to build with libgit2 1.8.x
    + Apply only if libgit2-devel >= 1.8
    + Fixes build in Factory
* Fri Mar  1 2024 Dirk Müller <dmueller@suse.com>
- update to 1.14.1:
  * Now `Object.filemode` returns `enums.FileMode` and
    `Reference.type` returns `enums.ReferenceType`
  * Fix tests on Fedora 40
  * Deprecate `ReferenceType.OID`, use `ReferenceType.DIRECT`
  * Deprecate `ReferenceType.LISTALL`, use `ReferenceType.ALL`
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * Drop support for Python 3.8
  * New `Repository.submodules` namespace
  * New `Repository.listall_mergeheads()`,
    `Repository.message`,
    `Repository.raw_message` and `Repository.remove_message()`
  * New `pygit2.enums` supersedes the `GIT_` constants
  * Now `Repository.status()`, `Repository.status_file()`,
    `Repository.merge_analysis()`, `DiffFile.flags`,
    `DiffFile.mode`,
    `DiffDelta.flags` and `DiffDelta.status` return enums
  * Now repository\'s `merge()`, `merge_commits()` and
    `merge_trees()`  take enums/flags for their `favor`,
    `flags` and `file_flags` arguments.
  * Fix crash in filter cleanup
  * Documentation fixes
  * Remove deprecated `Repository.create_remote(...)` function,
    use instead `Repository.remotes.create(...)`
  * Deprecate `Repository.add_submodule(...)`, use
    `Repository.submodules.add(...)`
  * Deprecate `Repository.lookup_submodule(...)`, use
    `Repository.submodules[...]`
  * Deprecate `Repository.init_submodules(...)`, use
    `Repository.submodules.init(...)`
  * Deprecate `Repository.update_submodule(...)`, use
    `Repository.submodules.update(...)`
  * Deprecate `GIT_*` constants, use `pygit2.enums`
  * Passign dicts to repository\'s `merge(...)`,
    `merge_commits(...)` and `merge_trees(...)` is deprecated.
    Instead pass `MergeFavor` for the `favor` argument, `MergeFlag`
    for `flags`, and `MergeFileFlag` for `file_flags`.
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.13.3:
  * New API for filters in Python #1237 #1244
  * Shallow repositories: New depth optional argument for
    clone_repository(...) and Remote.fetch(...) #1245 #1246
  * New submodule init(...), update(...) and reload(...)
    functions #1248
  * Release GIL in Walker.__next__ #1249
  * Type hints for submodule functions in Repository #1247
  * Support Python 3.12
  * Documentation updates #1242
  * Fix crash in reference rename #1233
  * Upgrade to libgit2 v1.7.1
  * Don't distribute wheels for pypy, only universal wheels for
    macOS
  * New Repository.remotes.create_anonymous(url) #1229
  * docs: update links to pypi, pygit2.org #1228
  * Prep work for Python 3.12 (not yet supported) #1223
- drop support-libgit2-1.7.patch (upstream)
* Tue Jul 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.12.2:
  + Update wheels to bundle libssh2 1.11.0 and OpenSSL 3.0.9.
    Remove obsolete Remote.save().
- Changes from version 1.12.1:
  + Fix segfault in signature when encoding is incorrect.
  + Typing improvements.
  + Update wheels to libgit2 v1.6.4.
- Changes from version 1.12.0:
  + Upgrade to libgit2 v1.6.3.
  + Update Linux wheels to bundle OpenSSL 3.0.8.
  + Downgrade Linux wheels to manylinux2014.
  + New ConflictCollection.__contains__.1
  + New Repository.references.iterator(...).
  + New favor, flags and file_flags optional arguments for
    Repository.merge(...).
  + New keep_all and paths optional arguments for
    Repository.stash(...).
  + New Respository.state().
  + Improve Repository.write_archive(...) performance.
  + Sync type annotations.
- Drop support-libgit2-1.6.patch: fixed upstream.
- Add support-libgit2-1.7.patch: support libgit2 1.7.0.
* Tue Mar 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add support-libgit2-1.6.patch to make it work with the latest
  libgit2 release gh#libgit2/pygit2#1200
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.11.1 (2022-11-09)
  * Fix Linux wheels, downgrade to manylinux 2_24 #1176
  * Windows wheels for Python 3.11 #1177
  * CI: Use 3.11 final release for testing #1178
  * Drop support for Python 3.7
  * Update Linux wheels to manylinux 2_28 #1136
  * Fix crash in signature representation #1162
  * Fix memory leak in Signature #1173
  * New optional argument raise_error in Repository.applies(...) #1166
  * New notify/progress callbacks for checkout and stash #1167 #1169
  * New Repository.remotes.names() #1159
  * Now refname argument in RemoteCallbacks.push_update_reference(...) is a string, not bytes #1168
  * Add missing newline at end of pygit2/decl/pack.h #1163
* Mon Sep 19 2022 Stephan Kulow <coolo@suse.com>
- Update to 1.10.1
  - Fix segfault in ``Signature`` repr
    `#1155 <https://github.com/libgit2/pygit2/pull/1155>`_
  - Linux and macOS wheels for Python 3.11
    `#1154 <https://github.com/libgit2/pygit2/pull/1154>`_
  - Upgrade to libgit2 1.5
  - Add support for ``GIT_OPT_GET_OWNER_VALIDATION`` and
    ``GIT_OPT_SET_OWNER_VALIDATION``
    `#1150 <https://github.com/libgit2/pygit2/pull/1150>`_
  - New ``untracked_files`` and ``ignored`` optional arguments for
    ``Repository.status(...)``
    `#1151 <https://github.com/libgit2/pygit2/pull/1151>`_
- Remove support-libgit-1.5.patch no longer needed
* Thu Jul 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.9.2:
  * New Repository.create_commit_string(...) and
    Repository.create_commit_with_signature(...) #1142
  * Linux and macOS wheels updated to libgit2 v1.4.3
  * Remove redundant line #1139
- Add patch support-libgit-1.5.patch:
  * Suppot libgit 1.5.0
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9.1:
  - Type hints: added to C code and Branches/References
  - New ``Signature`` supports ``str()`` and ``repr()``
  - Fix ODB backend's read in big endian architectures
  - Fix install with poetry
  - Wheels: update to libgit2 v1.4.2
  - Tests: fix testing ``parse_diff``
  - CI: various fixes after migration to libgit2 v1.4
* Mon Feb 28 2022 pgajdos@suse.com
- version update to 1.9.0
  1.9.0 (2022-02-22)
  - ------------------------
  - Upgrade to libgit2 v1.4
  - Documentation, new recipes for committing and cloning
    `#1125 <https://github.com/libgit2/pygit2/pull/1125>`_
  1.8.0 (2022-02-04)
  - ------------------------
  - Rename ``RemoteCallbacks.progress(...)`` callback to ``.sideband_progress(...)``
    `#1120 <https://github.com/libgit2/pygit2/pull/1120>`_
  - New ``Repository.merge_base_many(...)`` and ``Repository.merge_base_octopus(...)``
    `#1112 <https://github.com/libgit2/pygit2/pull/1112>`_
  - New ``Repository.listall_stashes()``
    `#1117 <https://github.com/libgit2/pygit2/pull/1117>`_
  - Code cleanup
    `#1118 <https://github.com/libgit2/pygit2/pull/1118>`_
  Backward incompatible changes:
  - The ``RemoteCallbacks.progress(...)`` callback has been renamed to
    ``RemoteCallbacks.sideband_progress(...)``. This matches the documentation,
    but may break existing code that still uses the old name.
  1.7.2 (2021-12-06)
  - ------------------------
  - Universal wheels for macOS
    `#1109 <https://github.com/libgit2/pygit2/pull/1109>`_
  1.7.1 (2021-11-19)
  - ------------------------
  - New ``Repository.amend_commit(...)``
    `#1098 <https://github.com/libgit2/pygit2/pull/1098>`_
  - New ``Commit.message_trailers``
    `#1101 <https://github.com/libgit2/pygit2/pull/1101>`_
  - Windows wheels for Python 3.10
    `#1103 <https://github.com/libgit2/pygit2/pull/1103>`_
  - Changed: now ``DiffDelta.is_binary`` returns ``None`` if the file data has
    not yet been loaded, cf. `#962 <https://github.com/libgit2/pygit2/issues/962>`_
  - Document ``Repository.get_attr(...)`` and update theme
    `#1017 <https://github.com/libgit2/pygit2/issues/1017>`_
    `#1105 <https://github.com/libgit2/pygit2/pull/1105>`_
* Wed Oct 20 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.7.0:
  - Upgrade to libgit2 1.3.0
  - Add support for Python 3.10
  - Drop support for Python 3.6
  - New `pygit2.GIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES`
  - New optional argument ``location`` in
    ``Repository.applies(..)`` and ``Repository.apply(..)``
  - Fix: Now the `flags` argument in `Repository.blame()` is
    passed through
  - CI: Stop using Travis, move to GitHub actions
  - Fix a number of reference leaks
  - Review custom object backends
  - In custom backends the callbacks have been renamed from ``read`` to
    ``read_cb``, ``write`` to ``write_cb``, and so on.
  - New optional ``proxy`` argument in ``Remote`` methods
  - New GIT_MERGE_PREFERENCE constants
  - Don't require cached-property with Python 3.8 or later
  - Refactored build and CI, new ``build.sh`` script
  - Remove deprecated ``GIT_CREDTYPE_XXX`` contants, use
    ``GIT_CREDENTIAL_XXX`` instead.
  - Remove deprecated ``Patch.patch`` getter, use ``Patch.text``
    instead.
  - New ``PackBuilder`` class and ``Repository.pack(...)``
  - New ``Config.delete_multivar(...)``
  - New ``Repository.is_shallow``
  - New optional ``message`` argument in
    ``Repository.create_reference(...)``
  - Fix truncated diff when there are nulls
  - Fix ``Index.add(...)`` raise ``TypeError`` instead of
    ``AttributeError`` when arguments are of unexpected type
  - Upgrade to libgit2 1.1, new ``GIT_BLAME_IGNORE_WHITESPACE`` constant
  - Drop support for PyPy3 7.2
  - New optional ``flags`` argument in ``Repository.__init__(...)``,
    new ``GIT_REPOSITORY_OPEN_*`` constants
- Remove upstreamed libgit2_1.patch.
* Sun Nov  1 2020 John Vandenberg <jayvdb@gmail.com>
- Add libgit2_1.patch for compatibility with libgit 1.1.0
- Update to v1.3.0
  * New Repository.applies, Repository.revparse, Repository.revparse_ext,
    Repository.add_submodule, Repository.raw_listall_branches, and
    Repository.raw_listall_references
  * New optional flags and file_flags arguments in
    Repository.merge_commits and Repository.merge_trees
  * New Reference.raw_target
  * Allow bytes in Repository.lookup_branch and Repository.diff
  * New GIT_BLAME_FIRST_PARENT and GIT_BLAME_USE_MAILMAP constants
  * New IndexEntry supports repr(), str(), == and !=
  * New Object supports repr()
  * New accept tuples of strings (not only lists) in a number of places
  * Fix compatibility with old macOS 10.9
  * Fix check argument type in Repository.apply(...)
  * Fix raise exception if error in Repository.listall_submodules()
  * Fix a couple of refcount errors in OdbBackend.refresh() and
    Worktree_is_prunable
* Wed May  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1:
  * Drop python2 support
  * Various crash fixes
* Mon Dec  2 2019 Julio González Gil <jgonzalez@suse.com>
- Fix building for s390x (bsc#1158198)
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.28.2:
  * Fix crash in reflog iteration #901
  * Support symbolic references in branches.with_commit(..) #910
  * Documentation updates #909
  * Test updates #911
* Wed May 15 2019 Gary Smith <GSmith@suse.com>
- Update to 0.28.1
  * Removed patch pycparser.patch as it is no longer needed
  * Now works with pycparser 2.18 and above
  * Now ``Repository.write_archive(..)`` keeps the file mode
  * New ``Patch.data`` returns the raw contents of the patch as a byte string
  * New ``Patch.text`` returns the contents of the patch as a text string,
* Mon Apr  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix the pycparser issues as per bellow:
  * pycparser.patch
* Sat Mar 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the pygit2-0.28-Remove-pycparser-constraint.patch and replace
  it with shorter sed
- Switch to pytest testing:
  * Fails now but that is pycparser bug https://github.com/eliben/pycparser/issues/305
- Disable tests temporarily as per above
* Wed Mar 20 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.28.0
  * Update to libgit2 v0.28
  * New ``pygit2.Mailmap``
  * New ``Repository.apply(...)`` wraps ``git_apply(..)``
  * Now ``Repository.merge_analysis(...)`` accepts an optional reference parameter
  * Now ``Repository.add_worktree(...)`` accepts an optional reference parameter
  * Now it's possible to set SSL certificate locations
  * Test and documentation improvements
  * Now ``worktree.path`` returns the path to the worktree directory
  * Remove undocumented ``worktree.git_path``
- Remove unneeded patch to fix issues on i586:
  * pygit2-i586.patch
- Add patch to remove unneeded constraint on pycparser
  * pygit2-0.28-Remove-pycparser-constraint.patch
* Mon May 21 2018 tchvatal@suse.com
- Add patch to fix issues on i586 arch:
  * pygit2-i586.patch
* Thu May 17 2018 tchvatal@suse.com
- Update to 0.27.0:
  * Update to libgit2 v0.27 #783
  * Fix for GCC 4 #786
* Thu Aug 24 2017 toddrme2178@gmail.com
- Update to 0.26.0
  * Update to libgit2 v0.26
  * Drop support for Python 3.2, add support for cffi 1.10
  * New ``Repository.revert_commit(...)``
  * New ``Branch.is_checked_out()``
  * Various fixes
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update to 0.25.0.
  * Make pygit2 throw if tree of a commit is not found
  * fixed cached memory tests
  * Added mwindow_mapped_limit, cached_memory, enable_caching,
    cache_max_size, cache_object_limit options
- Implement singlespec version.
* Wed Jan 11 2017 astieger@suse.com
- update to 0.24.2:
  * Fix when libgit2 error messages have non-ascii chars
  * Documentation improvements
- includes changes from 0.24.1
  * New Repository.listall_reference_objects()
  * Fix ``Repository.write_archive(...)`
  * Reproducible builds
  * Documentation fixes
* Wed Nov  2 2016 kkaempf@suse.com
- Fix Url link (old one was dead).
* Fri Aug 12 2016 tbechtold@suse.com
- require the cffi version it was built against
- Use pypi.io as Source url
* Thu Apr  7 2016 zaitor@opensuse.org
- Update to version 0.24.0:
  + Support Python 3.5.
  + New dependency, python-six
  + New Repository.path_is_ignored(path).
  + Fix error in Repository(path) when path is a bytes string.
  + Fix memory issue in Repository.describe(...).
  + Allow testing with `tox.
- Add python-six BuildRequires following upstream changes.
* Tue Sep 29 2015 toddrme2178@gmail.com
- Update to version 0.23.1
  * Improve support for cffi 1.0+
    (https://github.com/libgit2/pygit2/pull/529)
    (https://github.com/libgit2/pygit2/pull/561)
  * Fix Remote.push
    (https://github.com/libgit2/pygit2/pull/557)
  * New TreeEntry.type
    (https://github.com/libgit2/pygit2/pull/560)
  * New pygit2.GIT_DIFF_SHOW_BINARY
    (https://github.com/libgit2/pygit2/pull/566)
* Thu Sep 17 2015 p.drouand@gmail.com
- Update to version 0.23.0
  * Update to libgit2 v0.23
    (https://github.com/libgit2/pygit2/pull/540)
  * Now Repository.merge_base(...) returns None if no merge base is found
    (https://github.com/libgit2/pygit2/pull/550)
  * Documentation updates
    (https://github.com/libgit2/pygit2/pull/547)
* Tue Feb  3 2015 dimstar@opensuse.org
- Update to version 0.22.0:
  + Update to libgit2 v0.22
    (https://github.com/libgit2/pygit2/pull/459)
  + Add support for libgit2 feature detection (new pygit2.features
    and pygit2.GIT_FEATURE_*)
    (https://github.com/libgit2/pygit2/pull/475)
  + New Repository.remotes (RemoteCollection)
    (https://github.com/libgit2/pygit2/pull/447)
  + API Changes:
  - Prototype of clone_repository changed, check documentation
  - Removed clone_into, use clone_repository with callbacks instead
  - Use Repository.remotes.rename(name, new_name) instead of
    Remote.rename(new_name)
  - Use Repository.remotes.delete(name) instead of Remote.delete()
  - Now Remote.push(...) takes a list of refspecs instead of just one
  - Change Patch.old_id, Patch.new_id, Note.annotated_id,
    RefLogEntry.oid_old and RefLogEntry.oid_new to be Oid objects
    instead of strings
    (https://github.com/libgit2/pygit2/pull/449)
  + Other:
  - Fix init_repository when passing optional parameters
    workdir_path, description, template_path, initial_head or
    origin_url.
  - Fix use-after-free when patch outlives diff.
  - Documentation improvements.
  - Make the GPL exception explicit in setup.py.
- Add python-setuptools BuildRequires: new build dependency.
* Tue Sep  2 2014 p.drouand@gmail.com
- Update to version 0.20.2
  + Fix regression with Python 2, ``IndexEntry.path`` returns str
    (bytes in Python 2 and unicode in Python 3)
  + Get back ``IndexEntry.oid`` for backwards compatibility
  + Config, iterate over the keys (instead of the key/value pairs)
    `#395 <https://github.com/libgit2/pygit2/pull/395>`_
  + ``Diff.find_similar`` supports new threshold arguments
    `#396 <https://github.com/libgit2/pygit2/pull/396>`_
  + Optimization, do not load the object when expanding an oid prefix
  `#397 <https://github.com/libgit2/pygit2/pull/397>`_
- Changes from version 0.20.1
  + Install fix
    `#382 <https://github.com/libgit2/pygit2/pull/382>`_
  + Documentation improved, including
    `#383 <https://github.com/libgit2/pygit2/pull/383>`_
    `#385 <https://github.com/libgit2/pygit2/pull/385>`_
    `#388 <https://github.com/libgit2/pygit2/pull/388>`_
  + Documentation, use the read-the-docs theme
    `#387 <https://github.com/libgit2/pygit2/pull/387>`_
  + Coding style improvements
    `#392 <https://github.com/libgit2/pygit2/pull/392>`_
  + New ``Repository.state_cleanup()``
    `#386 <https://github.com/libgit2/pygit2/pull/386>`_
  + New ``Index.conflicts``
    `#345 <https://github.com/libgit2/pygit2/issues/345>`_
    `#389 <https://github.com/libgit2/pygit2/pull/389>`_
  + New checkout option to define the target directory
    `#390 <https://github.com/libgit2/pygit2/pull/390>`_
- Fix build
- Remove python_sitelib definition; pygit2 is arch dependant
- Add python-cffi and python-unittest2 requirements; new
  dependencies
- Disable tests; network is now needed for launching them
* Mon Dec  9 2013 p.drouand@gmail.com
- Update to version 0.20.0
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.19.0...v0.20.0
- Fix build on openSUSE >= 12.3 and SLE11SP3
- Remove obsolete conditionnal macros
* Sun Aug 18 2013 toddrme2178@gmail.com
- Update to 0.19.0
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.17.3...v0.19.0
- Keep 0.17.3 for compatibility with openSUSE 12.2
* Thu Dec 27 2012 cfarrell@suse.com
- license update: GPL-2.0
  See COPYING (and the majority of the source code files). Not sure why
  Apache-2.0 was chosen as license here - there is absolutely no indication
  of Apache style licensing in the package
* Tue Dec 18 2012 saschpe@suse.de
- Update to version 0.17.3:
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.17.2...v0.17.3
- Changes from previous versions:
  + https://github.com/libgit2/pygit2/compare/v0.16.1...v0.17.2
- Enable testsuite again
- Package file COPYING
* Tue Apr 24 2012 saschpe@suse.de
- Update to version 0.16.1:
  + Upstream provides no changelog
* Wed Jan 26 2011 saschpe@gmx.de
- Removed SUSE-specific --record-rpm for file lists
* Tue Jan 18 2011 saschpe@gmx.de
- Install documentation (README.md and COPYING)
- Fix install section for other distros
* Tue Jan 18 2011 saschpe@gmx.de
- Initial commit (0.1)
- Added patch include recent libgit2 changes
